..
  This file describes user-visible changes between the versions.

  subsections could include these headings (in this order), omit if no content

    Notice
    Breaking Changes
    New Features and/or Enhancements
    Fixes
    Maintenance
    Deprecations
    Contributors

Change History
##############

..
   1.0.
   ******

   release expected TBA

1.0.6 (developing)
******************

release expected TBA

Fixes
--------------

* Fixed *math domain error* in standard deviation functions.

Maintenance
--------------

* Add Python 3.12

1.0.5
******

released 2023-01-06

Enhancements
--------------

Provide older documentation versions from dropdown menu.

Fixes
--------------

Fixed "no content in dropdown menu" by pinning Sphinx<6.

1.0.4
******

released 2022-12-22

Fixes
--------------

* Version not reported correctly when run in certain directories.

1.0.3
******

released 2022-12-01

New Features
--------------

* Added ``x_at_min_y``

1.0.1
******

released 2022-11-27

Maintenance
-----------

* Removed unnecessary run-time packagaing requirements.

1.0.0
******

Initial project release: 2022-11-26
